@@ -3,6 +3,6 @@ from . import objects as objects
 from . import requests as bot
 from .base import UserProxyModel, Constants, exceptions as exc, UserModel
 from .context import ctx
-from .dispatcher import Dispatcher
+from .dispatcher import Dispatcher, Handler
 from .loader import logger
 from .utils import html
