@@ -1,4 +1,4 @@
-from .base import Handler
+from .base import HandlerOld
 from .. import filters
 from ..objects import CallbackButton
 
@@ -21,10 +21,10 @@ def button(
         _filters.append(filters.ChatType(chat_type))
 
     def _(func):
-        if isinstance(func, Handler):
+        if isinstance(func, HandlerOld):
             func = func.func
 
-        handler = Handler(func, _filters)
+        handler = HandlerOld(func, _filters)
         return handler
 
     return _
